==> scabbard-0.5.20.crate: scabbard-0.5.20/src/store/diesel/operations/get_current_commit_hash.rs <==
// Copyright 2021 Cargill Incorporated
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

use diesel::prelude::*;
use diesel::sql_types::Text;
use splinter::error::InternalError;

use crate::store::{diesel::schema::scabbard_commit_log, CommitHashStoreError};

use super::CommitHashStoreOperations;

pub(in crate::store::diesel) trait CommitHashStoreGetCurrentCommitHashOperation {
    fn get_current_commit_hash(
        &self,
        circuit_id: &str,
        service_id: &str,
    ) -> Result<Option<String>, CommitHashStoreError>;
}

impl<'a, C> CommitHashStoreGetCurrentCommitHashOperation for CommitHashStoreOperations<'a, C>
where
    C: diesel::Connection,
    String: diesel::deserialize::FromSql<Text, C::Backend>,
{
    fn get_current_commit_hash(
        &self,
        circuit_id: &str,
        service_id: &str,
    ) -> Result<Option<String>, CommitHashStoreError> {
        let current_commit_hash = scabbard_commit_log::table
            .find((circuit_id, service_id))
            .select(scabbard_commit_log::commit_hash)
            .get_result(self.conn)
            .optional()
            .map_err(|err| InternalError::from_source(Box::new(err)))?;

        Ok(current_commit_hash)
    }
}

==> scabbard-0.5.22.crate: scabbard-0.5.22/src/store/diesel/operations/get_current_commit_hash.rs <==
// Copyright 2021 Cargill Incorporated
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

use diesel::prelude::*;
use diesel::sql_types::Text;
use splinter::error::InternalError;

use crate::store::{diesel::schema::scabbard_commit_hash, CommitHashStoreError};

use super::CommitHashStoreOperations;

pub(in crate::store::diesel) trait CommitHashStoreGetCurrentCommitHashOperation {
    fn get_current_commit_hash(
        &self,
        circuit_id: &str,
        service_id: &str,
    ) -> Result<Option<String>, CommitHashStoreError>;
}

impl<'a, C> CommitHashStoreGetCurrentCommitHashOperation for CommitHashStoreOperations<'a, C>
where
    C: diesel::Connection,
    String: diesel::deserialize::FromSql<Text, C::Backend>,
{
    fn get_current_commit_hash(
        &self,
        circuit_id: &str,
        service_id: &str,
    ) -> Result<Option<String>, CommitHashStoreError> {
        let current_commit_hash = scabbard_commit_hash::table
            .find((circuit_id, service_id))
            .select(scabbard_commit_hash::commit_hash)
            .get_result(self.conn)
            .optional()
            .map_err(|err| InternalError::from_source(Box::new(err)))?;

        Ok(current_commit_hash)
    }
}
